## Partial Least Squares Package

Info text here.

### Installation

* `$ git clone https://github.com/b0nsaii/MBPLS.git`
* Install options 
    * Install as developing package
        * Move to /directory/to/MBPLS
        * `$ pip install -e .`
    * Add the directory to your systempath
        * `$ export PYTHONPATH="/directory/to/MBPLS:$PYTHONPATH"
* Now you can import the MBPLS class by typing\
`from mbpls.mbpls import MBPLS`